Module config

Module config 

Structs

BackendConfigV2
Configuration information for storage backend.
BlobCacheEntry
Configuration information for a cached blob.
BlobCacheEntryConfigV2
Configuration information for a cached blob`.
BlobCacheList
Configuration information for a list of cached blob objects.
CacheConfigV2
Configuration information for blob cache manager.
ConfigV2
Configuration file format version 2, based on Toml.
ConfigV2Internal
Internal runtime configuration.
ExternalBackendConfig
Additional configuration information for external backend, its items will be merged to the configuration from image.
FileCacheConfig
Configuration information for file cache.
FsCacheConfig
Configuration information for fscache.
HttpProxyConfig
Http proxy configuration information to access blobs.
LocalDiskConfig
Configuration information for localdisk storage backend.
LocalFsConfig
Configuration information for localfs storage backend.
OssConfig
OSS configuration information to access blobs.
OverlayConfig
Configuration information for Overlay filesystem. OverlayConfig is used to configure the writable layer(upper layer), The filesystem will be writable when OverlayConfig is set.
PrefetchConfigV2
Configuration information for blob data prefetching.
ProxyConfig
Configuration information for network proxy.
RafsConfigV2
Configuration information for RAFS filesystem.
RegistryConfig
Container registry configuration information to access blobs.
S3Config
S3 configuration information to access blobs.

Constants

BLOB_CACHE_TYPE_DATA_BLOB
Blob cache object type for nydus/rafs data blob.
BLOB_CACHE_TYPE_META_BLOB
Blob cache object type for nydus/rafs bootstrap blob.

Functions

default_prefetch_batch_size
default_user_io_batch_size