Structs
- Backend
Config V2 - Configuration information for storage backend.
- Blob
Cache Entry - Configuration information for a cached blob.
- Blob
Cache Entry Config V2 - Configuration information for a cached blob`.
- Blob
Cache List - Configuration information for a list of cached blob objects.
- Cache
Config V2 - Configuration information for blob cache manager.
- Config
V2 - Configuration file format version 2, based on Toml.
- Config
V2Internal - Internal runtime configuration.
- External
Backend Config - Additional configuration information for external backend, its items will be merged to the configuration from image.
- File
Cache Config - Configuration information for file cache.
- FsCache
Config - Configuration information for fscache.
- Http
Proxy Config - Http proxy configuration information to access blobs.
- Local
Disk Config - Configuration information for localdisk storage backend.
- Local
FsConfig - Configuration information for localfs storage backend.
- OssConfig
- OSS configuration information to access blobs.
- Overlay
Config - Configuration information for Overlay filesystem. OverlayConfig is used to configure the writable layer(upper layer), The filesystem will be writable when OverlayConfig is set.
- Prefetch
Config V2 - Configuration information for blob data prefetching.
- Proxy
Config - Configuration information for network proxy.
- Rafs
Config V2 - Configuration information for RAFS filesystem.
- Registry
Config - Container registry configuration information to access blobs.
- S3Config
- S3 configuration information to access blobs.
Constants
- BLOB_
CACHE_ TYPE_ DATA_ BLOB - Blob cache object type for nydus/rafs data blob.
- BLOB_
CACHE_ TYPE_ META_ BLOB - Blob cache object type for nydus/rafs bootstrap blob.